﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using Android.App;
using Android.Content;
using Android.OS;
using Android.Provider;
using Android.Runtime;
using Android.Support.V4.Content;
using Android.Views;
using Android.Webkit;
using Android.Widget;
using App19F_8;
using App19F_8.Droid;
using Java.IO;
using Xamarin.Forms;
using Xamarin.Forms.Platform.Android;

[assembly: ExportRenderer(typeof(CustomWebView), typeof(CustomWebViewRenderer))]
namespace App19F_8.Droid
{

    public class CustomWebViewRenderer : WebViewRenderer
    {
        const string JavascriptFunction = "function invokeCSharpAction(data){jsBridge.invokeAction(data);}";

        public CustomWebViewRenderer(Context context) : base(context)
        {
        }

        protected override void OnElementChanged(ElementChangedEventArgs<Xamarin.Forms.WebView> e)
        {
            base.OnElementChanged(e);

            if (e.OldElement != null)
            {
                Control.RemoveJavascriptInterface("jsBridge");
                ((CustomWebView)Element).Cleanup();
            }
            if (e.NewElement != null)
            {
                Control.SetWebChromeClient(new MyWebChromeClient(MainActivity.Instance));
                Control.Settings.JavaScriptEnabled = true;

                Control.Settings.UseWideViewPort = true;
                Control.Settings.LoadWithOverviewMode = true;
                Control.Settings.DomStorageEnabled = true;
                Control.Settings.DefaultTextEncodingName = "UTF-8";
                Control.SetWebViewClient(new MyWebViewClient(this));

                Control.LoadUrl("file:///android_asset/index.html");
            }

            //webView1.Settings.JavaScriptEnabled = true;
            //webView1.Settings.UseWideViewPort = true;
            //webView1.Settings.LoadWithOverviewMode = true;
            //webView1.Settings.DomStorageEnabled = true;
            //webView1.Settings.DefaultTextEncodingName = "UTF-8";
            //webView1.SetWebViewClient(new MyWebViewClient(this));
            //webView1.SetWebChromeClient(new myWebChromeClient(this));
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                ((CustomWebView)Element).Cleanup();
            }
            base.Dispose(disposing);
        }
    }

    public class MyWebViewClient : FormsWebViewClient
    {
        public MyWebViewClient(CustomWebViewRenderer renderer) : base(renderer)
        {
        }
    }

    public class MyWebChromeClient : WebChromeClient
    {
        Activity mActivity = null;
        public MyWebChromeClient(Activity activity)
        {
            mActivity = activity;
        }
        public override bool OnShowFileChooser(Android.Webkit.WebView webView, IValueCallback filePathCallback, FileChooserParams fileChooserParams)
        {
            MainActivity.mUploadCallbackAboveL = filePathCallback;
            //TakePhoto();

            File imageStorageDir = new File(Android.OS.Environment.GetExternalStoragePublicDirectory(Android.OS.Environment.DirectoryPictures), "MyAppFolder");

            if (!imageStorageDir.Exists())
            {
                imageStorageDir.Mkdirs();
            }

            // Create camera captured image file path and name, add ticks to make it unique 
            var file = new File(imageStorageDir + File.Separator + "IMG_" + DateTime.Now.Ticks + ".jpg");

            MainActivity.imageUri = Android.Net.Uri.FromFile(file);

            // Create camera capture image intent and add it to the chooser
            var captureIntent = new Intent(MediaStore.ActionImageCapture);
            captureIntent.PutExtra(MediaStore.ExtraOutput, MainActivity.imageUri);

            var i = new Intent(Intent.ActionGetContent);
            i.AddCategory(Intent.CategoryOpenable);
            i.SetType("image/*");

            var chooserIntent = Intent.CreateChooser(i, "Choose image");
            chooserIntent.PutExtra(Intent.ExtraInitialIntents, new Intent[] { captureIntent });

            MainActivity.Instance.StartActivityForResult(chooserIntent, MainActivity.PHOTO_REQUEST);

            return true;
        }

        //private void TakePhoto()
        //{
        //    File fileUri = new File(Android.OS.Environment.ExternalStorageDirectory.Path);
        //    if (Build.VERSION.SdkInt >= Android.OS.BuildVersionCodes.N)
        //    {
        //        if (!fileUri.Exists())
        //        {
        //            fileUri.Mkdir();
        //        }
        //        File file = new File(fileUri, SystemClock.CurrentThreadTimeMillis() + ".jpg");
        //        MainActivity.imageUri = FileProvider.GetUriForFile(mActivity, "com.companyname.app19f_8" + ".fileprovider", file);//通过FileProvider创建一个content类型的Uri
        //    }
        //    PhotoUtils.TakePicture(MainActivity.Instance, MainActivity.imageUri, MainActivity.PHOTO_REQUEST);
        //}
    }

    public class PhotoUtils
    {
        private static string TAG = "PhotoUtils";

        public static void TakePicture(Activity activity, Android.Net.Uri imageUri, int requestCode)
        {
            Intent intentCamera = new Intent();

            intentCamera.SetAction(MediaStore.ActionImageCapture);

            if (Build.VERSION.SdkInt >= Android.OS.BuildVersionCodes.N)
            {

                intentCamera.AddFlags(ActivityFlags.GrantReadUriPermission);
            }
            if (activity != null)
            {
                

                activity.StartActivityForResult(intentCamera, requestCode);
            }
        }
        public static void OpenPic(Activity activity, int requestCode)
        {
            Intent photoPickerIntent = new Intent(Intent.ActionGetContent);
            photoPickerIntent.SetType("image/*");
            activity.StartActivityForResult(photoPickerIntent, requestCode);
        }
    }
}